@@ -440,7 +440,7 @@ TQString BatchRenamer::findNumbers( TQString text, int count, int i )
     countervalues.start = m_index;
     countervalues.step = m_step;
 
-    if( text.contains( "#", FALSE ) <= 0 )
+    if( text.contains( "#", false ) <= 0 )
         return text;
 
     pos = text.find("#", pos);
@@ -538,10 +538,10 @@ TQString BatchRenamer::findBrackets( TQString oldname, TQString text, int i )
     int num, pos = -1, a;
     TQString token;
 
-    if( text.contains("]", FALSE) <= 0 || text.isEmpty() )
+    if( text.contains("]", false) <= 0 || text.isEmpty() )
         return text;
 
-    num = text.contains("[", FALSE);
+    num = text.contains("[", false);
     if(num <= 0 )
         return text;
 
