@@ -23,7 +23,7 @@
 
 class TQKeyEvent;
 class DSLineEdit : public KLineEdit {
-    Q_OBJECT
+    TQ_OBJECT
   
     public:
         DSLineEdit( TQWidget* parent = 0, const char* name = 0 );
@@ -46,7 +46,7 @@ class TQString;
  * the coordinates of a filename using an [x;y] token.
  */
 class CoordDialog : public KDialogBase  {
-    Q_OBJECT
+    TQ_OBJECT
   
     public: 
         CoordDialog( const TQString & file, TQWidget *_parent=0, const char *name=0);
