@@ -28,7 +28,7 @@ class KComboBox;
 class TQCheckBox;
 
 class EncodingPlugin : public Plugin  {
-    Q_OBJECT
+    TQ_OBJECT
   
     public:
         const TQString getName() const;
