@@ -24,7 +24,7 @@
 
 class TQString;
 class FileOperation: public TQObject {
-    Q_OBJECT
+    TQ_OBJECT
   
     public:
         FileOperation();
