@@ -23,7 +23,7 @@
 #include "guimodeselector.h"
 
 class FirstStartDlg : public KDialogBase, public GUIModeSelector {
-    Q_OBJECT
+    TQ_OBJECT
   
     public: 
         FirstStartDlg(TQWidget *parent=0, const char *name=0);
