@@ -18,13 +18,13 @@
 // Own includes
 #include "mydirplugin.h"
 
-// KDE includes
+// TDE includes
 #include <tdeapplication.h>
 #include <kiconloader.h>
 #include <tdefiledialog.h>
 #include <tdelocale.h>
 
-// QT includes
+// TQt includes
 #include <tqlabel.h>
 #include <tqlayout.h>
 #include <tqlineedit.h>
@@ -73,7 +73,7 @@ void MyDirPlugin::drawInterface( TQWidget* w, TQVBoxLayout* l )
 
     groupNumber = new TQGroupBox( w );
     groupNumber->setTitle( i18n( "&Options" ) );
-    groupNumber->setColumnLayout(0, Qt::Vertical );
+    groupNumber->setColumnLayout(0, TQt::Vertical );
     groupNumber->layout()->setSpacing( 6 );
     groupNumber->layout()->setMargin( 11 );
     groupNumberLayout = new TQHBoxLayout( groupNumber->layout() );
@@ -103,7 +103,7 @@ void MyDirPlugin::drawInterface( TQWidget* w, TQVBoxLayout* l )
 
     groupOutput = new TQGroupBox( w );
     groupOutput->setTitle( i18n( "Output &Directory" ) );
-    groupOutput->setColumnLayout(0, Qt::Vertical );
+    groupOutput->setColumnLayout(0, TQt::Vertical );
     groupOutput->layout()->setSpacing( 6 );
     groupOutput->layout()->setMargin( 11 );
     groupOutputLayout = new TQHBoxLayout( groupOutput->layout() );
@@ -120,7 +120,7 @@ void MyDirPlugin::drawInterface( TQWidget* w, TQVBoxLayout* l )
     l->addWidget( groupOutput );
     l->addItem( spacer2 );
 
-    connect( buttonDir, TQT_SIGNAL(clicked()), this, TQT_SLOT(chooseDir()));
+    connect( buttonDir, TQ_SIGNAL(clicked()), this, TQ_SLOT(chooseDir()));
 }
 
 void MyDirPlugin::fillStructure()
@@ -167,3 +167,4 @@ void MyDirPlugin::chooseDir()
         outputdir->setText( s );
 }
 
+#include "mydirplugin.moc"
