@@ -67,10 +67,10 @@ MyInputDialog::MyInputDialog( TQString filename, bool revertEnabled, TQWidget* p
     MyInputDialogLayout->addWidget( text );
     MyInputDialogLayout->addLayout( Layout );
 
-    connect( buttonCancel, TQT_SIGNAL( clicked() ), this, TQT_SLOT( reject() ) );
-    connect( buttonOk, TQT_SIGNAL( clicked() ), this, TQT_SLOT( accept() ) );
-    connect( buttonKrename, TQT_SIGNAL( clicked() ), this, TQT_SLOT( krename() ) );
-    connect( buttonFilename, TQT_SIGNAL( clicked() ), this, TQT_SLOT( slotFilename() ) );
+    connect( buttonCancel, TQ_SIGNAL( clicked() ), this, TQ_SLOT( reject() ) );
+    connect( buttonOk, TQ_SIGNAL( clicked() ), this, TQ_SLOT( accept() ) );
+    connect( buttonKrename, TQ_SIGNAL( clicked() ), this, TQ_SLOT( krename() ) );
+    connect( buttonFilename, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotFilename() ) );
 
     TQToolTip::add( buttonKrename, i18n("Use the filename that is generated by "
                                        "KRename instead of your changes." ) );
@@ -107,3 +107,4 @@ void MyInputDialog::slotFilename()
     text->setText( m_oldfilename );
 }
 
+#include "myinputdialog.moc"
