@@ -67,7 +67,7 @@ void ThreadedLister::run()
         m_reclister->setNameFilter( m_filter );
         m_reclister->setDirOnlyMode( m_dironly );
                 
-        connect( m_reclister, TQT_SIGNAL( completed() ), this, TQT_SLOT( reclisterFinished() ) );
+        connect( m_reclister, TQ_SIGNAL( completed() ), this, TQ_SLOT( reclisterFinished() ) );
         
         m_reclister->openURL( m_dirname );
     } else {
@@ -77,7 +77,7 @@ void ThreadedLister::run()
         m_lister->setShowingDotFiles( m_hidden );
         m_lister->setNameFilter( m_filter );
         
-        connect( m_lister, TQT_SIGNAL( completed() ), this, TQT_SLOT( listerFinished() ) );
+        connect( m_lister, TQ_SIGNAL( completed() ), this, TQ_SLOT( listerFinished() ) );
         
         m_lister->openURL( m_dirname, false, false );    
     }
