@@ -19,7 +19,7 @@
 #include "wizard.h"
 #include "krenameimpl.h"
 
-// KDE includes
+// TDE includes
 #include <tdeapplication.h>
 #include <kiconloader.h>
 #include <tdelocale.h>
@@ -42,9 +42,9 @@ wizard::wizard( KRenameImpl* impl, TQRect r, TQWidget* parent,  const char* name
 
     krename = impl ? impl : new KRenameImpl( this, menuBar, this->finishButton() );
 
-    connect( krename, TQT_SIGNAL( pageDone( TQWidget*, const TQString & ) ), this, TQT_SLOT( slotAddPage( TQWidget*, const TQString & ) ) );
-    connect( krename, TQT_SIGNAL( showPage( int ) ), this, TQT_SLOT( slotShowPage( int ) ) );
-    connect( krename, TQT_SIGNAL( enableFinish( bool ) ), this, TQT_SLOT( slotEnableFinish( bool ) ) );
+    connect( krename, TQ_SIGNAL( pageDone( TQWidget*, const TQString & ) ), this, TQ_SLOT( slotAddPage( TQWidget*, const TQString & ) ) );
+    connect( krename, TQ_SIGNAL( showPage( int ) ), this, TQ_SLOT( slotShowPage( int ) ) );
+    connect( krename, TQ_SIGNAL( enableFinish( bool ) ), this, TQ_SLOT( slotEnableFinish( bool ) ) );
 
     if( impl )
     {
@@ -104,3 +104,4 @@ void wizard::accept()
 /** do nothing */
 }
 
+#include "wizard.moc"
